@@ -45,6 +45,21 @@ class ApiSettings(ApiBase):
     def add_k8s_compute_service_under_cloud_account(self):
         return self.build_route("settings/cloudaccounts/computeservices/k8s")
 
+    def add_eks_compute_service(self):
+        return self.build_route("settings/computeservices/eks")
+
+    def get_eks_template(self):
+        return self.build_route("settings/computeservices/eks/template")
+
+    def get_aws_k8s_template(self):
+        return self.build_route("settings/cloudaccounts/aws/k8s/template")
+
+    def get_eks_agent_deployment_yaml(self):
+        return self.build_route("settings/computeservices/eks/agent-deployment-yaml")
+
+    def delete_compute_service(self):
+        return self.build_route("settings/cloudaccounts/computeservices")
+
     def aws_template(self):
         return self.build_route("settings/cloudaccounts/aws/template")
 
@@ -81,9 +96,18 @@ class ApiSettings(ApiBase):
     def repository_provider(self, name: str):
         return self.build_route(f"settings/repository_providers/{name}")
 
+    def terraform_modules(self):
+        return self.build_route(f"settings/tfmodules")
+
+    def terraform_module(self, module_name: str):
+        return self.build_route(f"settings/tfmodules/{module_name}")
+
     def k8s_agent_deployment_yaml(self, cloud_account_name: str, compute_service_name: str, sandbox_namespaces: str):
         return self.build_route("settings/cloudaccounts/computeservices/k8s/agent-deployment-yaml"
                                 "?cloudAccount={cloud_account_name}"
                                 "&computeService={compute_service_name}"
                                 "&sandboxNamespaces={sandbox_namespaces}"
                                 .format(**locals()))
+
+    def terraform_versions(self):
+        return self.build_route("settings/tfversion")
