@@ -10,7 +10,7 @@ from requests import Response
 from gateways.apis.api_route_base import ApiRoot
 from gateways.common.cs18_api_classes import BlueprintRepositoryDetails, AccessLink, \
     AddBlueprintUsingTokenRepositoryRequest, AddBlueprintGithubRepositoryRequest, \
-    AddBlueprintBitbucketRepositoryRequest, BitbucketBlueprintRepositoryDetails
+    AddBlueprintBitbucketRepositoryRequest, BitbucketBlueprintRepositoryDetails, TerraformModuleDescriptor
 from gateways.common.cs18_api_converters import Converters
 from gateways.common.cs18_api_errors import UnauthorizedException, SandboxNotFound, \
     SandboxEndingFailed
@@ -32,7 +32,8 @@ from gateways.common.cs18_api_responses import (AccountStatusResponse, Blueprint
                                                 BlueprintValidationResponse, AccountRepositoryDetailsResponse,
                                                 DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse,
                                                 ParameterStoreItem, RepositoryProviderResponse,
-                                                RepositoryRelationshipResponse, AccountExtraDetails)
+                                                RepositoryRelationshipResponse, AccountExtraDetails,
+                                                TerraformModuleDescriptorResponse)
 from gateways.n_session import NSession
 from gateways.the_gateway import TheGateway
 from gateways.utils import GatewayUtils, Utils
@@ -271,6 +272,62 @@ class Colony:
         resp = self.session.post(url=method_url, json=request)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
+    def add_eks_compute_service(self, cloud_account_name: str, name: str, agent_namespace: str,
+                                ingress_controller_type: str = "alb", ingress_class: str = "alb",
+                                configure_dns: bool = False,
+                                generate_certificate: bool = False):
+        method_url = self._api_root.settings.add_eks_compute_service()
+        request = {
+            'cloud_account_name': cloud_account_name,
+            'name': name,
+            'agent_namespace': agent_namespace,
+            'ingress_controller_type': ingress_controller_type,
+            'ingress_class': ingress_class,
+            'configure_dns': configure_dns,
+            'generate_certificate': generate_certificate,
+        }
+
+        resp = self.session.post(url=method_url, json=request)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+    def delete_compute_service(self, cloud_account_name: str, name: str):
+        method_url = self._api_root.settings.delete_compute_service()
+
+        request = {
+            'compute_service_name': cloud_account_name + "/" + name
+        }
+
+        resp = self.session.delete(url=method_url, json=request)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+    def get_eks_template(self, cloud_account_name: str, compute_service_name: str, sandboxes_namespace: str,
+                         oidc_provider_arn: str):
+        method_url = self._api_root.settings.get_aws_k8s_template()
+        params = {
+            'cloudAccount': cloud_account_name,
+            'computeService': compute_service_name,
+            'sandboxNamespaces': sandboxes_namespace,
+            'oidcProviderArn': oidc_provider_arn
+        }
+
+        resp = self.session.get(url=method_url, params=params)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        return resp.text
+
+    def get_eks_agent_deployment_yaml(self, cloud_account_name: str, compute_service_name: str,
+                                      sandboxes_namespace: str, role_arn: str):
+        method_url = self._api_root.settings.get_eks_agent_deployment_yaml()
+        params = {
+            'cloudAccount': cloud_account_name,
+            'computeService': compute_service_name,
+            'sandboxNamespace': sandboxes_namespace,
+            'roleArn': role_arn
+        }
+
+        resp = self.session.get(url=method_url, params=params)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        return resp.text
+
     def get_k8s_agent_deployment_yaml(self, cloud_account_name: str, compute_service_name: str,
                                       sandbox_namespaces: List[str]):
         method_url = self._api_root.settings.k8s_agent_deployment_yaml(cloud_account_name=cloud_account_name,
@@ -363,14 +420,21 @@ class Colony:
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
     def list_blueprints(
-            self, exclude_samples=False, deployment_type: str = None
+            self, exclude_samples=False, deployment_type: str = None,
+            branch: str = None, commit: str = None
     ) -> List[BlueprintResponse]:
         params = {}
         if deployment_type:
             params["type"] = deployment_type
+        if branch:
+            params["branch"] = branch
+        if commit:
+            params["commit"] = commit
         method_url = self._api_root.blueprint.blueprints_by_space_name(self.space)
         resp = self.session.get(url=method_url, params=params)
-        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        GatewayUtils.handle_response(response=resp, return_codes=[200, 400, 404])
+        if resp.status_code in [400, 404]:
+            return []
         blueprints_json = json.loads(resp.text)
         all_blueprints = [
             Converters.create_blueprint_response(blueprint)
@@ -725,7 +789,7 @@ class Colony:
 
         if wait_for_cache_refresh:
             Utils.wait_for(
-                func=lambda: (not self.list_blueprints(exclude_samples=True) is False),
+                func=lambda: (self.list_blueprints(exclude_samples=True) is not False),
                 interval_sec=5,
                 max_retries=24,
                 subject="blueprints ready",
@@ -753,7 +817,7 @@ class Colony:
 
         if wait_for_cache_refresh:
             Utils.wait_for(
-                func=lambda: (not self.list_blueprints(exclude_samples=True) is False),
+                func=lambda: (self.list_blueprints(exclude_samples=True) is not False),
                 interval_sec=5,
                 max_retries=24,
                 subject="blueprints ready",
@@ -766,7 +830,7 @@ class Colony:
 
         if wait_for_cache_refresh:
             Utils.wait_for(
-                func=lambda: (not self.list_blueprints(exclude_samples=True) is True),
+                func=lambda: (self.list_blueprints(exclude_samples=True) is not True),
                 interval_sec=5,
                 max_retries=24,
                 subject="blueprints removed",
@@ -1396,6 +1460,41 @@ class Colony:
 
         return resp
 
+    def add_terraform_modules_descriptor_to_account(self, request: TerraformModuleDescriptor):
+        method_url = self._api_root.settings.terraform_modules()
+        resp = self.session.post(url=method_url,  json=Utils.get_as_json(request))
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        return resp.text.replace('"', '')
+
+    def update_terraform_modules_descriptor_to_account(self, request: TerraformModuleDescriptor, module_name: str):
+        method_url = self._api_root.settings.terraform_module(module_name)
+        resp = self.session.put(url=method_url,  json=Utils.get_as_json(request))
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        return resp.text.replace('"', '')
+
+    def get_terraform_modules_descriptors(self) -> List[TerraformModuleDescriptorResponse]:
+        method_url = self._api_root.settings.terraform_modules()
+        resp = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        json_result = json.loads(resp.text)
+        return [Converters.create_terraform_module_descriptor_response(terraform_module)
+                for terraform_module in json_result]
+
+    def delete_terraform_modules_descriptor(
+            self,
+            descriptor_name: str
+    ):
+        method_url = self._api_root.settings.terraform_module(descriptor_name)
+
+        resp = self.session.delete(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+    def get_terraform_versions(self) -> List[str]:
+        method_url = self._api_root.settings.terraform_versions()
+        res = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=res, return_codes=[200])
+        return json.loads(res.text)
+
 
 class SandboxesHandler:
     def __init__(self):
