@@ -1,7 +1,8 @@
 from typing import List, Optional
 from datetime import datetime
 import dateutil.parser
-from gateways.common.cs18_api_classes import AccessLink
+from gateways.common.cs18_api_classes import AccessLink, TerraformModuleDescriptor, TerraformModuleComputeService, \
+    TerraformModuleInput, TerraformModuleOutput
 from gateways.common.cs18_api_errors import SandboxError, Error
 from gateways.common.cs18_api_requests import AwsCloudProviderSettingsModel
 from gateways.common.cs18_api_responses import (GetSpacesResponse, CreateAccountFinalizeResponse, ParameterStoreItem,
@@ -40,7 +41,8 @@ from gateways.common.cs18_api_responses import (GetSpacesResponse, CreateAccount
                                                 CloudAccountCostResponse, BlueprintResponse,
                                                 BlueprintValidationResponse, ArtifactRepoCreatedUser,
                                                 ArtifactRepoResponse, CatalogForGetAllResponse, CatalogForGetResponse,
-                                                SpaceCloudAccount, SpaceAdmin)
+                                                SpaceCloudAccount, SpaceAdmin, SandboxOutput, ServiceTfProgressResponse,
+                                                TerraformModuleDescriptorResponse)
 
 
 class Converters:
@@ -384,7 +386,8 @@ class Converters:
             debugging_service=sandbox.get('debugging_service'),
             launching_progress=Converters._create_launching_progress(sandbox.get('launching_progress')),
             source=Converters._create_source(sandbox.get('source')),
-            direct_access=sandbox.get('direct_access', 'off')
+            direct_access=sandbox.get('direct_access', 'off'),
+            outputs=Converters._create_sandbox_outputs(sandbox.get('outputs'))
         )
 
     @staticmethod
@@ -431,7 +434,8 @@ class Converters:
             has_green=production["has_green"],
             debugging_service=production.get('debugging_service'),
             launching_progress=Converters._create_launching_progress(production.get('launching_progress')),
-            direct_access=production.get('direct_access', 'off')
+            direct_access=production.get('direct_access', 'off'),
+            outputs=Converters._create_sandbox_outputs(production['outputs'])
         )
 
     @staticmethod
@@ -467,7 +471,8 @@ class Converters:
             exposure=production["exposure"],
             debugging_service=production.get('debugging_service'),
             launching_progress=Converters._create_launching_progress(production.get('launching_progress')),
-            direct_access=production.get('direct_access', 'off')
+            direct_access=production.get('direct_access', 'off'),
+            outputs=Converters._create_sandbox_outputs(production['outputs'])
         )
 
     @staticmethod
@@ -923,10 +928,18 @@ class Converters:
 
     @staticmethod
     def _create_service_response(service: dict) -> ServiceResponse:
+        progress_dict = service["progress"]
+        if progress_dict:
+            progress = ServiceTfProgressResponse(tf_plan_status=progress_dict["terraform_plan"],
+                                                 tf_apply_status=progress_dict["terraform_apply"],
+                                                 tf_destroy_status=progress_dict["terraform_destroy"])
+        else:
+            progress = None
         return ServiceResponse(
             name=service["name"],
             status=service["status"],
-            service_type=service["type"]
+            service_type=service["type"],
+            progress=progress
         )
 
     @staticmethod
@@ -1082,3 +1095,76 @@ class Converters:
             first_name=data['first_name'],
             last_name=data['last_name']
         )
+
+    @staticmethod
+    def _create_sandbox_outputs(data: Optional[List]) -> Optional[List[SandboxOutput]]:
+        if data is None:
+            return None
+        return [SandboxOutput(name=d["name"],
+                              value=d["value"],
+                              display_style=d["display_style"],
+                              description=d["description"])
+                for d in data]
+
+    @staticmethod
+    def create_terraform_module_descriptor_response(module: dict) -> TerraformModuleDescriptorResponse:
+        return TerraformModuleDescriptorResponse(
+            module_name=module.get("name", None),
+            module_repo_name=module.get("module_repo_name", None),
+            module_root_path=module.get("module_root_path", None),
+            description=module.get("description", None),
+            terraform_version=module.get("terraform_version", None),
+            enable_auto_tagging=module.get("enable_auto_tagging", None),
+            exclude_from_tagging=module.get("exclude_from_tagging", None),
+            inputs=[Converters.create_terraform_module_input_response(module_input)
+                    for module_input in module["inputs"]],
+            outputs=[Converters.create_terraform_module_input_response(module_input)
+                     for module_input in module["outputs"]],
+            compute_services=[Converters.create_terraform_module_compute_service_response(compute_service)
+                              for compute_service in module["compute_services"]],
+            allowed_spaces=module.get("allowed_spaces", None),
+            created_date=module.get("created_date", None),
+            created_by=module.get("created_by", None),
+            last_modified=module.get("last_modified", None),
+            modified_by=module.get("modified_by", None)
+        )
+
+    @staticmethod
+    def create_terraform_module_compute_service_response(module: dict) -> TerraformModuleComputeService:
+        return TerraformModuleComputeService(
+            cloud_account_name=module.get("cloud_account_name", None),
+            compute_service_name=module.get("compute_service_name", None),
+            permissions=module.get("permissions", None)
+        )
+
+    @staticmethod
+    def create_terraform_module_input_response(module: dict) -> TerraformModuleInput:
+        return TerraformModuleInput(
+            name=module.get("name"), value=module.get("value"), description=module.get("description"),
+            optional=module.get("optional"), overridable=module.get("overridable"),
+            display_style=module.get("display_style")
+        )
+
+    @staticmethod
+    def create_terraform_module_output_response(module: dict) -> TerraformModuleOutput:
+        return TerraformModuleOutput(
+            name=module.get("name"), description=module.get("description"),
+            display_style=module.get("display_style")
+        )
+
+    @staticmethod
+    def terraform_module_descriptor_to_dictionary(module: TerraformModuleDescriptor) -> dict:
+        request: dict = {
+            "name": module.name,
+            "module_repo_name": module.module_repo_name,
+            "module_root_path": module.module_root_path,
+            "description": module.description,
+            "terraform_version": module.terraform_version,
+            "enable_auto_tagging": module.enable_auto_tagging,
+            "exclude_from_tagging": module.exclude_from_tagging,
+            "inputs": module.inputs,
+            "outputs": module.outputs,
+            "compute_services": module.compute_services,
+            "allowed_spaces": module.allowed_spaces
+        }
+        return request
