@@ -77,6 +77,7 @@ class CreateAccountRequest:
             email: str,
             password: str,
             phone_number: str,
+            company_name: str = None,
             utm_campaign: str = "",
     ):
         self.phone_number = phone_number
@@ -85,6 +86,7 @@ class CreateAccountRequest:
         self.last_name = last_name
         self.first_name = first_name
         self.account_name = account_name
+        self.company_name = company_name
         self.utm_campaign = utm_campaign
 
 
@@ -111,8 +113,9 @@ class AwsCloudProviderSettingsModel:
         self.sidecar_image_param_name = sidecar_image_param_name
 
 
-class InsidedTokenResponseModel:
-    def __init__(self, access_token: str, expires_in: int, token_type: str):
-        self. access_token = access_token
-        self. token_type = token_type
-        self.expires_in = expires_in
+class NewUserSurveyRequest:
+    def __init__(self, roles: List[str] = None, primary_technologies: List[str] = None,
+                 primary_platforms: List[str] = None) -> None:
+        self.roles = roles if roles is not None else []
+        self.primary_technologies = primary_technologies if primary_technologies is not None else []
+        self.primary_platforms = primary_platforms if primary_platforms is not None else []
