@@ -8,7 +8,8 @@ from datetime import datetime
 from enum import Enum
 from typing import List, Dict, Optional
 
-from gateways.common.cs18_api_classes import AccessLink
+from gateways.common.cs18_api_classes import AccessLink, TerraformModuleDescriptor, \
+    TerraformModuleInput, TerraformModuleComputeService
 from gateways.common.cs18_api_errors import SandboxError, Error
 
 
@@ -460,14 +461,38 @@ class InputResponse:
         self.name = name
 
 
+class SandboxOutput:
+    def __init__(self,
+                 name: str,
+                 value: str,
+                 display_style: str,
+                 description: str):
+        self.name = name
+        self.value = value
+        self.display_style = display_style
+        self.description = description
+
+
+class ServiceTfProgressResponse:
+    def __init__(self,
+                 tf_plan_status: str,
+                 tf_apply_status: str,
+                 tf_destroy_status: str):
+        self.tf_plan_status = tf_plan_status
+        self.tf_apply_status = tf_apply_status
+        self.tf_destroy_status = tf_destroy_status
+
+
 class ServiceResponse:
     def __init__(self,
                  name: str,
                  service_type: str,
-                 status: str):
+                 status: str,
+                 progress: ServiceTfProgressResponse):
         self.name = name
         self.type = service_type
         self.status = status
+        self.progress = progress
 
 
 class SandboxResponse(SandboxResponseBase):
@@ -492,7 +517,8 @@ class SandboxResponse(SandboxResponseBase):
                  debugging_service: str,
                  launching_progress: LaunchingProgress,
                  source: BlueprintSourceResponse,
-                 direct_access: str):
+                 direct_access: str,
+                 outputs: Optional[List[SandboxOutput]]):
         super().__init__(sandbox_status,
                          create_time,
                          start_time,
@@ -514,6 +540,7 @@ class SandboxResponse(SandboxResponseBase):
         self.applications = applications
         self.services = services
         self.launching_progress = launching_progress
+        self.outputs = outputs
 
 
 class SandboxResponseLean(SandboxResponseBase):
@@ -612,7 +639,8 @@ class ProductionResponse(metaclass=abc.ABCMeta):
             links: List[HyperlinkResponse],
             debugging_service: str,
             launching_progress: LaunchingProgress,
-            direct_access: str):
+            direct_access: str,
+            outputs: Optional[List[SandboxOutput]]):
         self.production_id = production_id
         self.sandbox_id = sandbox_id
         self.name = name
@@ -635,6 +663,7 @@ class ProductionResponse(metaclass=abc.ABCMeta):
         self.debugging_service = debugging_service
         self.launching_progress = launching_progress
         self.direct_access = direct_access
+        self.outputs = outputs
 
 
 class ProductionBlueResponse(ProductionResponse):
@@ -661,7 +690,8 @@ class ProductionBlueResponse(ProductionResponse):
                  has_green: bool,
                  debugging_service: str,
                  launching_progress: LaunchingProgress,
-                 direct_access: str):
+                 direct_access: str,
+                 outputs: Optional[List[SandboxOutput]]):
         super().__init__(
             production_id=production_id,
             sandbox_id=sandbox_id,
@@ -684,7 +714,8 @@ class ProductionBlueResponse(ProductionResponse):
             links=links,
             debugging_service=debugging_service,
             launching_progress=launching_progress,
-            direct_access=direct_access)
+            direct_access=direct_access,
+            outputs=outputs)
         self.has_green = has_green
 
 
@@ -712,7 +743,8 @@ class ProductionGreenResponse(ProductionResponse):
                  exposure: int,
                  debugging_service: str,
                  launching_progress: LaunchingProgress,
-                 direct_access: str):
+                 direct_access: str,
+                 outputs: Optional[List[SandboxOutput]]):
         super().__init__(
             production_id=production_id,
             sandbox_id=sandbox_id,
@@ -735,7 +767,8 @@ class ProductionGreenResponse(ProductionResponse):
             links=links,
             debugging_service=debugging_service,
             launching_progress=launching_progress,
-            direct_access=direct_access)
+            direct_access=direct_access,
+            outputs=outputs)
         self.exposure = exposure
 
 
@@ -955,7 +988,6 @@ class AccountRepositoryResponse:
 class RepositoryRelationshipResponse:
     def __init__(self, repo_relationship_id: str, space_id: str, deployment_type: str,
                  account_id: str, branch: str, is_valid: bool, errors: List[Error]):
-
         self.repo_relationship_id = repo_relationship_id
         self.account_id = account_id
         self.space_id = space_id
@@ -1171,3 +1203,25 @@ class CreateAccountFinalizeResponse:
         self.user_email = user_email
         self.first_name = first_name
         self.last_name = last_name
+
+
+class TerraformModuleDescriptorResponse(TerraformModuleDescriptor):
+    def __init__(self, module_name: str = None, module_repo_name: str = None, module_root_path: str = None,
+                 description: str = None, terraform_version: str = None, enable_auto_tagging: bool = None,
+                 exclude_from_tagging: List[str] = None, inputs: List[TerraformModuleInput] = None,
+                 outputs: List[TerraformModuleInput] = None,
+                 compute_services: List[TerraformModuleComputeService] = None,
+                 allowed_spaces: List[str] = None, modified_by: str = None, last_modified: datetime = None,
+                 created_by: str = None, created_date: datetime = None):
+        super().__init__(module_name, module_repo_name, module_root_path, description,
+                         terraform_version, enable_auto_tagging, exclude_from_tagging,
+                         inputs, outputs, compute_services, allowed_spaces)
+        self.created_date = created_date
+        self.created_by = created_by
+        self.last_modified = last_modified
+        self.modified_by = modified_by
+
+    def __eq__(self, other):
+        if not isinstance(other, TerraformModuleDescriptor):
+            return NotImplemented
+        return super(TerraformModuleDescriptorResponse, self).__eq__(other)
